# Anthropic Claude
- [Anthropic Claude](https://console.anthropic.com/docs/access)
- [AGiXT](https://github.com/Josh-XT/AGiXT)

## Quick Start Guide
### Update your agent settings
1. Set `AI_PROVIDER` to `claude`.
2. Set `ANTHROPIC_API_KEY` to your OpenAI API key.
3. Set `AI_MODEL` to `claude-v1-100k` for the 100k model, or `claude-v1` for the regular model.
4. Set `AI_TEMPERATURE` to a value between 0 and 1. The higher the value, the more creative the output.
5. Set `MAX_TOKENS` to the maximum number of tokens to generate. 